@@ -675,25 +675,14 @@ def unique_tree(**kwargs):
         # patch the init method
         orig_init = decorated_cls.__init__
         def __init__(self, *args, **kwargs):
-            if getattr(self, "_child_indices", None) is None:
-                self._child_indices = []
-            if getattr(self, "_parent_indices", None) is None:
-                self._parent_indices = []
-            if getattr(self, "_all_indices", None) is None:
-                self._all_indices = []
-
             # register the child index
             child_index = UniqueObjectIndex(cls=cls)
             setattr(self, "_" + plural, child_index)
-            self._child_indices.append(child_index)
-            self._all_indices.append(child_index)
 
             # register the child index
             if parents:
                 parent_index = UniqueObjectIndex(cls=cls)
                 setattr(self, "_parent_" + plural, parent_index)
-                self._parent_indices.append(parent_index)
-                self._all_indices.append(parent_index)
 
             # call the original inint
             orig_init(self, *args, **kwargs)
@@ -875,10 +864,15 @@ def unique_tree(**kwargs):
             def get_leaves(self):
                 """
                 Returns all child {plural} from the :py:attr:`{plural}` index that have no child
-                {plural} themselves in a recursive fashion.
+                {plural} themselves in a recursive fashion. Possible duplicates due to nested
+                structures are removed.
                 """
                 walker = getattr(self, "walk_" + plural)()
-                return [obj for obj, _, objs in walker if not objs]
+                leaves = []
+                for obj, _, objs in walker:
+                    if not objs and obj not in leaves:
+                        leaves.append(obj)
+                return leaves
 
         #
         # child methods, disabled parents
@@ -1146,10 +1140,15 @@ def unique_tree(**kwargs):
                 def get_roots(self):
                     """
                     Returns all parent {plural} from the :py:attr:`parent_{plural}` index that have
-                    no parent {plural} themselves in a recursive fashion.
+                    no parent {plural} themselves in a recursive fashion. Possible duplicates due to
+                    nested structures are removed.
                     """
                     walker = getattr(self, "walk_parent_" + plural)()
-                    return [obj for obj, _, objs in walker if not objs]
+                    roots = []
+                    for obj, _, objs in walker:
+                        if not objs and obj not in roots:
+                            roots.append(obj)
+                    return roots
 
         #
         # parent methods, exactly 1 parent
